@@ -1,15 +1,18 @@
 """Command proxies."""
 
-from __future__ import annotations
+from contextlib import suppress
 from enum import Enum
 from functools import wraps
 from json import dumps
 from re import fullmatch
-from typing import Callable, Generator, Iterable, Iterator
+from typing import Callable, Iterable, Iterator
+
+from mcipc.rcon.types import IntRange
 
 
 __all__ = [
     'boolmap',
+    'int_range_to_str',
     'parsed',
     'str_until_none',
     'stringify',
@@ -33,6 +36,20 @@ def boolmap(text: str, true: str = None, false: str = None, *,
     return default
 
 
+def int_range_to_str(int_range: IntRange) -> str:
+    """Returns a string for the Minecraft server."""
+
+    start, end = int_range
+
+    if start == end:
+        if start is not None:
+            return str(start)
+
+        raise ValueError('Either start or end need to be specified.')
+
+    return '..'.join(map(lambda i: '' if i is None else str(i), int_range))
+
+
 def parsed(parser: Callable[[str], type]) -> Callable[[Callable], Callable]:
     """Updates a function to parse its result with a parser."""
 
@@ -43,8 +60,13 @@ def parsed(parser: Callable[[str], type]) -> Callable[[Callable], Callable]:
             """Wrapper function thats parses the function's return value."""
             return parser(function(*args, **kwargs))
 
-        if 'return' in parser.__annotations__:
-            inner.__annotations__['return'] = parser.__annotations__['return']
+        try:
+            annotations = parser.__annotations__
+        except AttributeError:
+            inner.__annotations__['return'] = parser
+        else:
+            with suppress(KeyError):
+                inner.__annotations__['return'] = annotations['return']
 
         return inner
 
@@ -63,13 +85,10 @@ def stringify(value: type) -> str:
     if isinstance(value, str):
         return value
 
-    if isinstance(value, bool):
-        return 'true' if value else 'false'
-
-    if isinstance(value, dict):
+    if isinstance(value, (bool, dict, list)):
         return dumps(value)
 
-    if isinstance(value, (list, tuple)):
+    if isinstance(value, tuple):
         return ' '.join(map(stringify, value))
 
     if isinstance(value, Enum):
@@ -78,7 +97,7 @@ def stringify(value: type) -> str:
     return str(value)
 
 
-def until_none(items: Iterable[type]) -> Generator[type, None, None]:
+def until_none(items: Iterable[type]) -> Iterator[type]:
     """Yields items until one item is None."""
 
     for item in items:
